from setuptools import setup

setup(name='gdbd_distributions',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['gdbd_distributions'],
      author = 'Sourabh Rustagi',
      author_email = 'sourabhrustagi1@gmail.com',
      zip_safe=False)
